@@ -37,10 +37,10 @@ message_routing_opt = [
 ]
 
 rabbit_opts = [
-    cfg.StrOpt('host',
-               help='The RabbitMQ broker address which used for communication '
-               'with Murano guest agents.',
-               default='localhost'),
+    cfg.HostAddressOpt('host',
+                       help='The RabbitMQ broker address which used for '
+                            'communication with Murano guest agents.',
+                       default='localhost'),
     cfg.IntOpt('port', help='The RabbitMQ broker port.', default=5672),
     cfg.StrOpt('login',
                help='The RabbitMQ login.',
@@ -56,6 +56,12 @@ rabbit_opts = [
                 help='Boolean flag to enable SSL communication through the '
                 'RabbitMQ broker between murano-engine and guest agents.',
                 default=False),
+    cfg.StrOpt('ssl_version',
+               default='',
+               help='SSL version to use (valid only if SSL enabled). '
+                    'Valid values are TLSv1 and SSLv23. SSLv2, SSLv3, '
+                    'TLSv1_1, and TLSv1_2 may be available on some '
+                    'distributions.'),
     cfg.StrOpt('ca_certs',
                help='SSL cert file (valid only if SSL enabled).',
                default=''),
